A date range picker for Bootstrap

# Configuration Builder

parentEl
startDate
endDate
minDate
maxDate
autoApply
singleDatePicker
showDropdowns
showWeekNumbers
showISOWeekNumbers
timePicker
timePicker24Hour
timePickerIncrement (in minutes)
timePickerSeconds
dateLimit (with example date range span)
ranges (with example predefined ranges)
locale (with example settings) RTL (right-to-left)
alwaysShowCalendars
linkedCalendars
autoUpdateInput
showCustomRangeLabel
opens
drops
buttonClasses
applyClass
cancelClass

#### Your Date Range Picker

#### Configuration